# Gemini Trust Store Generators

Geminispace is (currently) small enough that we can afford to download all known capsules' TLS certificates and use them to generate trust stores for various Gemini clients.  If verified via multiple network perspectives, using a pre-generated trust store is a major improvement over blindly trusting-on-first-use.

This repo contains scripts for:

1. downloading a list of hosts from [geminispace.info](gemini://geminispace.info/known-hosts) and [Lupa](gemini://gemini.bortzmeyer.org/software/lupa/lupa-capsules.txt)
2. downloading the TLS certificates of those hosts
3. generating a table containing details about each certificate
4. generating trust stores for various Gemini clients, currently:

* [Agunua](agunua/)
* [Amfora](amfora/)
* [Lagrange](lagrange/)

Trust stores generated by these scripts can be found at https://tildegit.org/nervuri/trust-stores

## Dependencies

Required: [OpenSSL](https://www.openssl.org/), [idn](https://www.gnu.org/software/libidn/)

Optional: [torsocks](https://packages.debian.org/buster/torsocks) (for .onion capsules and for double-checking certificates using a different network perspective)

To install them in Debian, run: `sudo apt install openssl idn torsocks`

## Usage

`./main.sh` will run all scripts.  For the [trust stores repo](https://tildegit.org/nervuri/trust-stores), I use `time ./main.sh >log-stdout 2>log-stderr`.  For 893 hosts, the command takes around 80 minutes to complete with Tor verification and 45 minutes without.

`get-certs.sh` accepts `tor` as an optional argument, to double-check certificates using the Tor network.  If you have `torsocks` installed, this option will automatically be used when you run `./main.sh`.

All trust store generators accept certificate expiry boundaries as arguments.  Ex:

```
./generate.sh          # all certs
./generate.sh 90+      # certs that will expire in more than 90 days from now
./generate.sh 30-      # certs that have expired more than 30 days ago
./generate.sh 30- 90+  # both of the above; in other words, certs are excluded if:
                       # {30 days ago} < cert_expiry < {90 days from now}
```

This is to assist client developers who wish to bundle pre-generated trust stores with their clients, but only want to include long-lived (and long-expired) certificates.

## How to contribute

The project is hosted [at tildegit.org](https://tildegit.org/nervuri/trust-store-generators).  If you don't want to make an account, just [shoot me an email](https://nervuri.net/contact) with your [patch](https://git-send-email.io/)/suggestion/bug report/whatever else.
